This is the mail archive of the crossgcc@sourceware.org mailing list for the crossgcc project.

See crosstool-NG for lots more information.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[PATCH 1/3] binutils: Added ranlib to tools list


# HG changeset patch
# User Ray Donnelly <mingw.android@gmail.com>
# Date 1391499645 0
#      Tue Feb 04 07:40:45 2014 +0000
# Node ID 2eab7ceda925402555d7d3107e5828734ac74c11
# Parent  529a71ea091e8ffa34d8b62f82e0996e3927750d
binutils: Added ranlib to tools list

so that it is available to available to
the core C compiler build because static
libraries are built and ranlib is used
on them.

Signed-off-by: Ray Donnelly <mingw.android@gmail.com>

diff -r 529a71ea091e -r 2eab7ceda925 scripts/build/binutils/binutils.sh
--- a/scripts/build/binutils/binutils.sh Thu Jan 16 14:55:23 2014 -0800
+++ b/scripts/build/binutils/binutils.sh Tue Feb 04 07:40:45 2014 +0000
@@ -106,13 +106,13 @@
     fi

     # Make those new tools available to the core C compilers to come.
     # Note: some components want the ${TARGET}-{ar,as,ld,strip} commands as
     # well. Create that.
     # Don't do it for canadian or cross-native, because the binutils
     # are not executable on the build machine.
     case "${CT_TOOLCHAIN_TYPE}" in
         cross|native)
-            binutils_tools=( ar as ld strip )
+            binutils_tools=( ar as ld ranlib strip )
             if [ -n "${CT_ARCH_BINFMT_FLAT}" ]; then
                 binutils_tools+=( elf2flt flthdr )
             fi
@@ -106,13 +106,13 @@

     # Make those new tools available to the core C compilers to come.
-    # Note: some components want the ${TARGET}-{ar,as,ld,strip} commands as
-    # well. Create that.
+    # Note: some components want the ${TARGET}-{ar,as,ld,ranlib,strip} commands
+    # as well. Create that.
     # Don't do it for canadian or cross-native, because the binutils
     # are not executable on the build machine.

--
For unsubscribe information see http://sourceware.org/lists.html#faq


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]